# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_conditions/v1/tick_conditions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick_conditions/v1/tick_conditions.proto',
  package='systemathics.apis.services.tick_conditions.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCsystemathics/apis/services/tick_conditions/v1/tick_conditions.proto\x12-systemathics.apis.services.tick_conditions.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\x8a\x01\n\x15TickConditionsRequest\x12\x42\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierH\x00\x12\x12\n\x08\x65xchange\x18\x02 \x01(\tH\x00\x12\x10\n\x06source\x18\x03 \x01(\x05H\x00\x42\x07\n\x05value\"`\n\x16TickConditionsResponse\x12\x46\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x38.systemathics.apis.services.tick_conditions.v1.Condition\"b\n\tCondition\x12\r\n\x05value\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x0f\n\x07regular\x18\x04 \x01(\x08\x12\x0f\n\x07\x61uction\x18\x05 \x01(\x08\x32\xb7\x01\n\x15TickConditionsService\x12\x9d\x01\n\x0eTickConditions\x12\x44.systemathics.apis.services.tick_conditions.v1.TickConditionsRequest\x1a\x45.systemathics.apis.services.tick_conditions.v1.TickConditionsResponseb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_TICKCONDITIONSREQUEST = _descriptor.Descriptor(
  name='TickConditionsRequest',
  full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest.exchange', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest.source', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsRequest.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=170,
  serialized_end=308,
)


_TICKCONDITIONSRESPONSE = _descriptor.Descriptor(
  name='TickConditionsResponse',
  full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=406,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='systemathics.apis.services.tick_conditions.v1.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.tick_conditions.v1.Condition.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='systemathics.apis.services.tick_conditions.v1.Condition.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comment', full_name='systemathics.apis.services.tick_conditions.v1.Condition.comment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regular', full_name='systemathics.apis.services.tick_conditions.v1.Condition.regular', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auction', full_name='systemathics.apis.services.tick_conditions.v1.Condition.auction', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=408,
  serialized_end=506,
)

_TICKCONDITIONSREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKCONDITIONSREQUEST.oneofs_by_name['value'].fields.append(
  _TICKCONDITIONSREQUEST.fields_by_name['identifier'])
_TICKCONDITIONSREQUEST.fields_by_name['identifier'].containing_oneof = _TICKCONDITIONSREQUEST.oneofs_by_name['value']
_TICKCONDITIONSREQUEST.oneofs_by_name['value'].fields.append(
  _TICKCONDITIONSREQUEST.fields_by_name['exchange'])
_TICKCONDITIONSREQUEST.fields_by_name['exchange'].containing_oneof = _TICKCONDITIONSREQUEST.oneofs_by_name['value']
_TICKCONDITIONSREQUEST.oneofs_by_name['value'].fields.append(
  _TICKCONDITIONSREQUEST.fields_by_name['source'])
_TICKCONDITIONSREQUEST.fields_by_name['source'].containing_oneof = _TICKCONDITIONSREQUEST.oneofs_by_name['value']
_TICKCONDITIONSRESPONSE.fields_by_name['data'].message_type = _CONDITION
DESCRIPTOR.message_types_by_name['TickConditionsRequest'] = _TICKCONDITIONSREQUEST
DESCRIPTOR.message_types_by_name['TickConditionsResponse'] = _TICKCONDITIONSRESPONSE
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickConditionsRequest = _reflection.GeneratedProtocolMessageType('TickConditionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKCONDITIONSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.TickConditionsRequest)
  })
_sym_db.RegisterMessage(TickConditionsRequest)

TickConditionsResponse = _reflection.GeneratedProtocolMessageType('TickConditionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKCONDITIONSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.TickConditionsResponse)
  })
_sym_db.RegisterMessage(TickConditionsResponse)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'systemathics.apis.services.tick_conditions.v1.tick_conditions_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_conditions.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)



_TICKCONDITIONSSERVICE = _descriptor.ServiceDescriptor(
  name='TickConditionsService',
  full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=509,
  serialized_end=692,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickConditions',
    full_name='systemathics.apis.services.tick_conditions.v1.TickConditionsService.TickConditions',
    index=0,
    containing_service=None,
    input_type=_TICKCONDITIONSREQUEST,
    output_type=_TICKCONDITIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKCONDITIONSSERVICE)

DESCRIPTOR.services_by_name['TickConditionsService'] = _TICKCONDITIONSSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_prices.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/daily/v1/daily_prices.proto',
  package='systemathics.apis.services.daily.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6systemathics/apis/services/daily/v1/daily_prices.proto\x12#systemathics.apis.services.daily.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xae\x01\n\x12\x44\x61ilyPricesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"T\n\x13\x44\x61ilyPricesResponse\x12=\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32/.systemathics.apis.services.daily.v1.DailyPrice\"[\n\nDailyPrice\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x97\x01\n\x12\x44\x61ilyPricesService\x12\x80\x01\n\x0b\x44\x61ilyPrices\x12\x37.systemathics.apis.services.daily.v1.DailyPricesRequest\x1a\x38.systemathics.apis.services.daily.v1.DailyPricesResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_DAILYPRICESREQUEST = _descriptor.Descriptor(
  name='DailyPricesRequest',
  full_name='systemathics.apis.services.daily.v1.DailyPricesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.daily.v1.DailyPricesRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.daily.v1.DailyPricesRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.daily.v1.DailyPricesRequest.adjustment', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=397,
)


_DAILYPRICESRESPONSE = _descriptor.Descriptor(
  name='DailyPricesResponse',
  full_name='systemathics.apis.services.daily.v1.DailyPricesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.daily.v1.DailyPricesResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=483,
)


_DAILYPRICE = _descriptor.Descriptor(
  name='DailyPrice',
  full_name='systemathics.apis.services.daily.v1.DailyPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.daily.v1.DailyPrice.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='systemathics.apis.services.daily.v1.DailyPrice.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='systemathics.apis.services.daily.v1.DailyPrice.volume', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='systemathics.apis.services.daily.v1.DailyPrice.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=576,
)

_DAILYPRICESREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DAILYPRICESREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DAILYPRICESRESPONSE.fields_by_name['data'].message_type = _DAILYPRICE
_DAILYPRICE.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['DailyPricesRequest'] = _DAILYPRICESREQUEST
DESCRIPTOR.message_types_by_name['DailyPricesResponse'] = _DAILYPRICESRESPONSE
DESCRIPTOR.message_types_by_name['DailyPrice'] = _DAILYPRICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DailyPricesRequest = _reflection.GeneratedProtocolMessageType('DailyPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICESREQUEST,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPricesRequest)
  })
_sym_db.RegisterMessage(DailyPricesRequest)

DailyPricesResponse = _reflection.GeneratedProtocolMessageType('DailyPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICESRESPONSE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPricesResponse)
  })
_sym_db.RegisterMessage(DailyPricesResponse)

DailyPrice = _reflection.GeneratedProtocolMessageType('DailyPrice', (_message.Message,), {
  'DESCRIPTOR' : _DAILYPRICE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_prices_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyPrice)
  })
_sym_db.RegisterMessage(DailyPrice)



_DAILYPRICESSERVICE = _descriptor.ServiceDescriptor(
  name='DailyPricesService',
  full_name='systemathics.apis.services.daily.v1.DailyPricesService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=579,
  serialized_end=730,
  methods=[
  _descriptor.MethodDescriptor(
    name='DailyPrices',
    full_name='systemathics.apis.services.daily.v1.DailyPricesService.DailyPrices',
    index=0,
    containing_service=None,
    input_type=_DAILYPRICESREQUEST,
    output_type=_DAILYPRICESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAILYPRICESSERVICE)

DESCRIPTOR.services_by_name['DailyPricesService'] = _DAILYPRICESSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_trades_and_book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import mappings_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2
from systemathics.apis.type.shared.v1 import market_fields_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import book_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2
from systemathics.apis.type.shared.v1 import trade_and_book_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__and__book__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick/v1/tick_trades_and_book.proto',
  package='systemathics.apis.services.tick.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=systemathics/apis/services/tick/v1/tick_trades_and_book.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/mappings.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a:systemathics/apis/type/shared/v1/market_book_updates.proto\x1a<systemathics/apis/type/shared/v1/market_fields_updates.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a+systemathics/apis/type/shared/v1/book.proto\x1a\x35systemathics/apis/type/shared/v1/trade_and_book.proto\"\xa1\x01\n\x18TickTradesAndBookRequest\x12\x41\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\xa1\x01\n\x19TickTradesAndBookResponse\x12>\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32..systemathics.apis.type.shared.v1.TradeAndBookH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\xaf\x01\n\x18TickTradesAndBookService\x12\x92\x01\n\x11TickTradesAndBook\x12<.systemathics.apis.services.tick.v1.TickTradesAndBookRequest\x1a=.systemathics.apis.services.tick.v1.TickTradesAndBookResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__and__book__pb2.DESCRIPTOR,])




_TICKTRADESANDBOOKREQUEST = _descriptor.Descriptor(
  name='TickTradesAndBookRequest',
  full_name='systemathics.apis.services.tick.v1.TickTradesAndBookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifiers', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookRequest.identifiers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=761,
)


_TICKTRADESANDBOOKRESPONSE = _descriptor.Descriptor(
  name='TickTradesAndBookResponse',
  full_name='systemathics.apis.services.tick.v1.TickTradesAndBookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookResponse.mapping', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickTradesAndBookResponse.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=764,
  serialized_end=925,
)

_TICKTRADESANDBOOKREQUEST.fields_by_name['identifiers'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKTRADESANDBOOKREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKTRADESANDBOOKRESPONSE.fields_by_name['data'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__and__book__pb2._TRADEANDBOOK
_TICKTRADESANDBOOKRESPONSE.fields_by_name['mapping'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2._KEYS
_TICKTRADESANDBOOKRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKTRADESANDBOOKRESPONSE.fields_by_name['data'])
_TICKTRADESANDBOOKRESPONSE.fields_by_name['data'].containing_oneof = _TICKTRADESANDBOOKRESPONSE.oneofs_by_name['payload']
_TICKTRADESANDBOOKRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKTRADESANDBOOKRESPONSE.fields_by_name['mapping'])
_TICKTRADESANDBOOKRESPONSE.fields_by_name['mapping'].containing_oneof = _TICKTRADESANDBOOKRESPONSE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['TickTradesAndBookRequest'] = _TICKTRADESANDBOOKREQUEST
DESCRIPTOR.message_types_by_name['TickTradesAndBookResponse'] = _TICKTRADESANDBOOKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickTradesAndBookRequest = _reflection.GeneratedProtocolMessageType('TickTradesAndBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADESANDBOOKREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_trades_and_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickTradesAndBookRequest)
  })
_sym_db.RegisterMessage(TickTradesAndBookRequest)

TickTradesAndBookResponse = _reflection.GeneratedProtocolMessageType('TickTradesAndBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADESANDBOOKRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_trades_and_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickTradesAndBookResponse)
  })
_sym_db.RegisterMessage(TickTradesAndBookResponse)



_TICKTRADESANDBOOKSERVICE = _descriptor.ServiceDescriptor(
  name='TickTradesAndBookService',
  full_name='systemathics.apis.services.tick.v1.TickTradesAndBookService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=928,
  serialized_end=1103,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickTradesAndBook',
    full_name='systemathics.apis.services.tick.v1.TickTradesAndBookService.TickTradesAndBook',
    index=0,
    containing_service=None,
    input_type=_TICKTRADESANDBOOKREQUEST,
    output_type=_TICKTRADESANDBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKTRADESANDBOOKSERVICE)

DESCRIPTOR.services_by_name['TickTradesAndBookService'] = _TICKTRADESANDBOOKSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/constraints.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import time_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_time__interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/constraints.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2systemathics/apis/type/shared/v1/constraints.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/dayofweek.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a\x34systemathics/apis/type/shared/v1/time_interval.proto\"\xf7\x01\n\x0b\x43onstraints\x12\x46\n\x0e\x64\x61te_intervals\x18\x01 \x03(\x0b\x32..systemathics.apis.type.shared.v1.DateInterval\x12\x46\n\x0etime_intervals\x18\x02 \x03(\x0b\x32..systemathics.apis.type.shared.v1.TimeInterval\x12)\n\x0e\x65xcluded_dates\x18\x03 \x03(\x0b\x32\x11.google.type.Date\x12-\n\rexcluded_days\x18\x04 \x03(\x0e\x32\x16.google.type.DayOfWeekb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,google_dot_type_dot_dayofweek__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_time__interval__pb2.DESCRIPTOR,])




_CONSTRAINTS = _descriptor.Descriptor(
  name='Constraints',
  full_name='systemathics.apis.type.shared.v1.Constraints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date_intervals', full_name='systemathics.apis.type.shared.v1.Constraints.date_intervals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_intervals', full_name='systemathics.apis.type.shared.v1.Constraints.time_intervals', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_dates', full_name='systemathics.apis.type.shared.v1.Constraints.excluded_dates', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_days', full_name='systemathics.apis.type.shared.v1.Constraints.excluded_days', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=497,
)

_CONSTRAINTS.fields_by_name['date_intervals'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2._DATEINTERVAL
_CONSTRAINTS.fields_by_name['time_intervals'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_time__interval__pb2._TIMEINTERVAL
_CONSTRAINTS.fields_by_name['excluded_dates'].message_type = google_dot_type_dot_date__pb2._DATE
_CONSTRAINTS.fields_by_name['excluded_days'].enum_type = google_dot_type_dot_dayofweek__pb2._DAYOFWEEK
DESCRIPTOR.message_types_by_name['Constraints'] = _CONSTRAINTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Constraints = _reflection.GeneratedProtocolMessageType('Constraints', (_message.Message,), {
  'DESCRIPTOR' : _CONSTRAINTS,
  '__module__' : 'systemathics.apis.type.shared.v1.constraints_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Constraints)
  })
_sym_db.RegisterMessage(Constraints)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/date_interval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/date_interval.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4systemathics/apis/type/shared/v1/date_interval.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\"Z\n\x0c\x44\x61teInterval\x12%\n\nstart_date\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12#\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x11.google.type.Dateb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,])




_DATEINTERVAL = _descriptor.Descriptor(
  name='DateInterval',
  full_name='systemathics.apis.type.shared.v1.DateInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_date', full_name='systemathics.apis.type.shared.v1.DateInterval.start_date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='systemathics.apis.type.shared.v1.DateInterval.end_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=204,
)

_DATEINTERVAL.fields_by_name['start_date'].message_type = google_dot_type_dot_date__pb2._DATE
_DATEINTERVAL.fields_by_name['end_date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['DateInterval'] = _DATEINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DateInterval = _reflection.GeneratedProtocolMessageType('DateInterval', (_message.Message,), {
  'DESCRIPTOR' : _DATEINTERVAL,
  '__module__' : 'systemathics.apis.type.shared.v1.date_interval_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.DateInterval)
  })
_sym_db.RegisterMessage(DateInterval)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/market_fields_updates.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import action_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2
from systemathics.apis.type.shared.v1 import field_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_field__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/market_fields_updates.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<systemathics/apis/type/shared/v1/market_fields_updates.proto\x12 systemathics.apis.type.shared.v1\x1a-systemathics/apis/type/shared/v1/action.proto\x1a,systemathics/apis/type/shared/v1/field.proto\"p\n\x13MarketFieldsUpdates\x12\x13\n\x0bis_snapshot\x18\x01 \x01(\x08\x12\x44\n\x07updates\x18\x02 \x03(\x0b\x32\x33.systemathics.apis.type.shared.v1.MarketFieldUpdate\"\xd4\x01\n\x11MarketFieldUpdate\x12\x38\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32(.systemathics.apis.type.shared.v1.Action\x12\x36\n\x05\x66ield\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Field\x12\x14\n\nlong_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x05 \x01(\tH\x00\x42\x07\n\x05valueb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_field__pb2.DESCRIPTOR,])




_MARKETFIELDSUPDATES = _descriptor.Descriptor(
  name='MarketFieldsUpdates',
  full_name='systemathics.apis.type.shared.v1.MarketFieldsUpdates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_snapshot', full_name='systemathics.apis.type.shared.v1.MarketFieldsUpdates.is_snapshot', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updates', full_name='systemathics.apis.type.shared.v1.MarketFieldsUpdates.updates', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=303,
)


_MARKETFIELDUPDATE = _descriptor.Descriptor(
  name='MarketFieldUpdate',
  full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.field', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.long_value', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.double_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.string_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='systemathics.apis.type.shared.v1.MarketFieldUpdate.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=306,
  serialized_end=518,
)

_MARKETFIELDSUPDATES.fields_by_name['updates'].message_type = _MARKETFIELDUPDATE
_MARKETFIELDUPDATE.fields_by_name['action'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_action__pb2._ACTION
_MARKETFIELDUPDATE.fields_by_name['field'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_field__pb2._FIELD
_MARKETFIELDUPDATE.oneofs_by_name['value'].fields.append(
  _MARKETFIELDUPDATE.fields_by_name['long_value'])
_MARKETFIELDUPDATE.fields_by_name['long_value'].containing_oneof = _MARKETFIELDUPDATE.oneofs_by_name['value']
_MARKETFIELDUPDATE.oneofs_by_name['value'].fields.append(
  _MARKETFIELDUPDATE.fields_by_name['double_value'])
_MARKETFIELDUPDATE.fields_by_name['double_value'].containing_oneof = _MARKETFIELDUPDATE.oneofs_by_name['value']
_MARKETFIELDUPDATE.oneofs_by_name['value'].fields.append(
  _MARKETFIELDUPDATE.fields_by_name['string_value'])
_MARKETFIELDUPDATE.fields_by_name['string_value'].containing_oneof = _MARKETFIELDUPDATE.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['MarketFieldsUpdates'] = _MARKETFIELDSUPDATES
DESCRIPTOR.message_types_by_name['MarketFieldUpdate'] = _MARKETFIELDUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MarketFieldsUpdates = _reflection.GeneratedProtocolMessageType('MarketFieldsUpdates', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFIELDSUPDATES,
  '__module__' : 'systemathics.apis.type.shared.v1.market_fields_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketFieldsUpdates)
  })
_sym_db.RegisterMessage(MarketFieldsUpdates)

MarketFieldUpdate = _reflection.GeneratedProtocolMessageType('MarketFieldUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MARKETFIELDUPDATE,
  '__module__' : 'systemathics.apis.type.shared.v1.market_fields_updates_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.MarketFieldUpdate)
  })
_sym_db.RegisterMessage(MarketFieldUpdate)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_bollinger.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/daily_analytics/v1/daily_bollinger.proto',
  package='systemathics.apis.services.daily_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCsystemathics/apis/services/daily_analytics/v1/daily_bollinger.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xd4\x01\n\x15\x44\x61ilyBollingerRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x11\n\tdeviation\x18\x04 \x01(\x01\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"i\n\x16\x44\x61ilyBollingerResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.daily_analytics.v1.DailyBollingerData\"\xcc\x01\n\x12\x44\x61ilyBollingerData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12+\n\x05lower\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05upper\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06middle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue2\xb7\x01\n\x15\x44\x61ilyBollingerService\x12\x9d\x01\n\x0e\x44\x61ilyBollinger\x12\x44.systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest\x1a\x45.systemathics.apis.services.daily_analytics.v1.DailyBollingerResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_DAILYBOLLINGERREQUEST = _descriptor.Descriptor(
  name='DailyBollingerRequest',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest.length', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviation', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest.deviation', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest.adjustment', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=490,
)


_DAILYBOLLINGERRESPONSE = _descriptor.Descriptor(
  name='DailyBollingerResponse',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=492,
  serialized_end=597,
)


_DAILYBOLLINGERDATA = _descriptor.Descriptor(
  name='DailyBollingerData',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerData.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerData.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerData.lower', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upper', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerData.upper', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='middle', full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerData.middle', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=804,
)

_DAILYBOLLINGERREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DAILYBOLLINGERREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DAILYBOLLINGERRESPONSE.fields_by_name['data'].message_type = _DAILYBOLLINGERDATA
_DAILYBOLLINGERDATA.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
_DAILYBOLLINGERDATA.fields_by_name['lower'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_DAILYBOLLINGERDATA.fields_by_name['upper'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_DAILYBOLLINGERDATA.fields_by_name['middle'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
DESCRIPTOR.message_types_by_name['DailyBollingerRequest'] = _DAILYBOLLINGERREQUEST
DESCRIPTOR.message_types_by_name['DailyBollingerResponse'] = _DAILYBOLLINGERRESPONSE
DESCRIPTOR.message_types_by_name['DailyBollingerData'] = _DAILYBOLLINGERDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DailyBollingerRequest = _reflection.GeneratedProtocolMessageType('DailyBollingerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBOLLINGERREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyBollingerRequest)
  })
_sym_db.RegisterMessage(DailyBollingerRequest)

DailyBollingerResponse = _reflection.GeneratedProtocolMessageType('DailyBollingerResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBOLLINGERRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyBollingerResponse)
  })
_sym_db.RegisterMessage(DailyBollingerResponse)

DailyBollingerData = _reflection.GeneratedProtocolMessageType('DailyBollingerData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYBOLLINGERDATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyBollingerData)
  })
_sym_db.RegisterMessage(DailyBollingerData)



_DAILYBOLLINGERSERVICE = _descriptor.ServiceDescriptor(
  name='DailyBollingerService',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=807,
  serialized_end=990,
  methods=[
  _descriptor.MethodDescriptor(
    name='DailyBollinger',
    full_name='systemathics.apis.services.daily_analytics.v1.DailyBollingerService.DailyBollinger',
    index=0,
    containing_service=None,
    input_type=_DAILYBOLLINGERREQUEST,
    output_type=_DAILYBOLLINGERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAILYBOLLINGERSERVICE)

DESCRIPTOR.services_by_name['DailyBollingerService'] = _DAILYBOLLINGERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/memo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/memo.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+systemathics/apis/type/shared/v1/memo.proto\x12 systemathics.apis.type.shared.v1\"G\n\x04Memo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0e\n\x06stream\x18\x03 \x01(\t\x12\x0e\n\x06ticker\x18\x04 \x01(\tb\x06proto3'
)




_MEMO = _descriptor.Descriptor(
  name='Memo',
  full_name='systemathics.apis.type.shared.v1.Memo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='systemathics.apis.type.shared.v1.Memo.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='systemathics.apis.type.shared.v1.Memo.group', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='systemathics.apis.type.shared.v1.Memo.stream', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='systemathics.apis.type.shared.v1.Memo.ticker', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=152,
)

DESCRIPTOR.message_types_by_name['Memo'] = _MEMO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Memo = _reflection.GeneratedProtocolMessageType('Memo', (_message.Message,), {
  'DESCRIPTOR' : _MEMO,
  '__module__' : 'systemathics.apis.type.shared.v1.memo_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.Memo)
  })
_sym_db.RegisterMessage(Memo)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import mappings_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2
from systemathics.apis.type.shared.v1 import market_book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2
from systemathics.apis.type.shared.v1 import market_fields_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import book_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick/v1/tick_book.proto',
  package='systemathics.apis.services.tick.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2systemathics/apis/services/tick/v1/tick_book.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/mappings.proto\x1a,systemathics/apis/type/shared/v1/level.proto\x1a:systemathics/apis/type/shared/v1/market_book_updates.proto\x1a<systemathics/apis/type/shared/v1/market_fields_updates.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a+systemathics/apis/type/shared/v1/book.proto\"\x98\x01\n\x0fTickBookRequest\x12\x41\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\x96\x01\n\x10TickBookResponse\x12<\n\x05limit\x18\x01 \x01(\x0b\x32+.systemathics.apis.type.shared.v1.BookLimitH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\x8a\x01\n\x0fTickBookService\x12w\n\x08TickBook\x12\x33.systemathics.apis.services.tick.v1.TickBookRequest\x1a\x34.systemathics.apis.services.tick.v1.TickBookResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_mappings__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__book__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_market__fields__updates__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2.DESCRIPTOR,])




_TICKBOOKREQUEST = _descriptor.Descriptor(
  name='TickBookRequest',
  full_name='systemathics.apis.services.tick.v1.TickBookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifiers', full_name='systemathics.apis.services.tick.v1.TickBookRequest.identifiers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick.v1.TickBookRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=534,
  serialized_end=686,
)


_TICKBOOKRESPONSE = _descriptor.Descriptor(
  name='TickBookResponse',
  full_name='systemathics.apis.services.tick.v1.TickBookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='systemathics.apis.services.tick.v1.TickBookResponse.limit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.tick.v1.TickBookResponse.mapping', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='systemathics.apis.services.tick.v1.TickBookResponse.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=689,
  serialized_end=839,
)

_TICKBOOKREQUEST.fields_by_name['identifiers'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKBOOKREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKBOOKRESPONSE.fields_by_name['limit'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__pb2._BOOKLIMIT
_TICKBOOKRESPONSE.fields_by_name['mapping'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2._KEYS
_TICKBOOKRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKBOOKRESPONSE.fields_by_name['limit'])
_TICKBOOKRESPONSE.fields_by_name['limit'].containing_oneof = _TICKBOOKRESPONSE.oneofs_by_name['payload']
_TICKBOOKRESPONSE.oneofs_by_name['payload'].fields.append(
  _TICKBOOKRESPONSE.fields_by_name['mapping'])
_TICKBOOKRESPONSE.fields_by_name['mapping'].containing_oneof = _TICKBOOKRESPONSE.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['TickBookRequest'] = _TICKBOOKREQUEST
DESCRIPTOR.message_types_by_name['TickBookResponse'] = _TICKBOOKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickBookRequest = _reflection.GeneratedProtocolMessageType('TickBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOOKREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickBookRequest)
  })
_sym_db.RegisterMessage(TickBookRequest)

TickBookResponse = _reflection.GeneratedProtocolMessageType('TickBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKBOOKRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickBookResponse)
  })
_sym_db.RegisterMessage(TickBookResponse)



_TICKBOOKSERVICE = _descriptor.ServiceDescriptor(
  name='TickBookService',
  full_name='systemathics.apis.services.tick.v1.TickBookService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=842,
  serialized_end=980,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickBook',
    full_name='systemathics.apis.services.tick.v1.TickBookService.TickBook',
    index=0,
    containing_service=None,
    input_type=_TICKBOOKREQUEST,
    output_type=_TICKBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKBOOKSERVICE)

DESCRIPTOR.services_by_name['TickBookService'] = _TICKBOOKSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/field.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/field.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,systemathics/apis/type/shared/v1/field.proto\x12 systemathics.apis.type.shared.v1*\xdd\x04\n\x05\x46ield\x12\x15\n\x11\x46IELD_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46IELD_OPEN_PRICE\x10\x01\x12\x13\n\x0f\x46IELD_OPEN_SIZE\x10\x02\x12\x15\n\x11\x46IELD_CLOSE_PRICE\x10\x03\x12\x14\n\x10\x46IELD_CLOSE_SIZE\x10\x04\x12\x13\n\x0f\x46IELD_LOW_PRICE\x10\x05\x12\x12\n\x0e\x46IELD_LOW_SIZE\x10\x06\x12\x14\n\x10\x46IELD_HIGH_PRICE\x10\x07\x12\x13\n\x0f\x46IELD_HIGH_SIZE\x10\x08\x12\x15\n\x11\x46IELD_TRADE_PRICE\x10\t\x12\x14\n\x10\x46IELD_TRADE_SIZE\x10\n\x12\x1b\n\x17\x46IELD_TRADING_CONDITION\x10\x0b\x12\x15\n\x11\x46IELD_TRADE_COUNT\x10\x0c\x12\x19\n\x15\x46IELD_TRADE_OTC_PRICE\x10\r\x12\x18\n\x14\x46IELD_TRADE_OTC_SIZE\x10\x0e\x12\x19\n\x15\x46IELD_TRADE_OTC_COUNT\x10\x0f\x12\x10\n\x0c\x46IELD_VOLUME\x10\x10\x12\x17\n\x13\x46IELD_VWAP_OFFICIAL\x10\x11\x12\x19\n\x15\x46IELD_VWAP_ELECTRONIC\x10\x12\x12\x1b\n\x17\x46IELD_THEORETICAL_PRICE\x10\x13\x12\x1a\n\x16\x46IELD_THEORETICAL_SIZE\x10\x14\x12\x15\n\x11\x46IELD_UPPER_PRICE\x10\x15\x12\x15\n\x11\x46IELD_LOWER_PRICE\x10\x16\x12\x13\n\x0f\x46IELD_VARIATION\x10\x17\x12\x1e\n\x1a\x46IELD_VARIATION_PERCENTAGE\x10\x18\x62\x06proto3'
)

_FIELD = _descriptor.EnumDescriptor(
  name='Field',
  full_name='systemathics.apis.type.shared.v1.Field',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIELD_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_OPEN_PRICE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_OPEN_SIZE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_CLOSE_PRICE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_CLOSE_SIZE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_LOW_PRICE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_LOW_SIZE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_HIGH_PRICE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_HIGH_SIZE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_PRICE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_SIZE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADING_CONDITION', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_COUNT', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_OTC_PRICE', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_OTC_SIZE', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_TRADE_OTC_COUNT', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VOLUME', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VWAP_OFFICIAL', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VWAP_ELECTRONIC', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_THEORETICAL_PRICE', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_THEORETICAL_SIZE', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_UPPER_PRICE', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_LOWER_PRICE', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VARIATION', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIELD_VARIATION_PERCENTAGE', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=83,
  serialized_end=688,
)
_sym_db.RegisterEnumDescriptor(_FIELD)

Field = enum_type_wrapper.EnumTypeWrapper(_FIELD)
FIELD_UNSPECIFIED = 0
FIELD_OPEN_PRICE = 1
FIELD_OPEN_SIZE = 2
FIELD_CLOSE_PRICE = 3
FIELD_CLOSE_SIZE = 4
FIELD_LOW_PRICE = 5
FIELD_LOW_SIZE = 6
FIELD_HIGH_PRICE = 7
FIELD_HIGH_SIZE = 8
FIELD_TRADE_PRICE = 9
FIELD_TRADE_SIZE = 10
FIELD_TRADING_CONDITION = 11
FIELD_TRADE_COUNT = 12
FIELD_TRADE_OTC_PRICE = 13
FIELD_TRADE_OTC_SIZE = 14
FIELD_TRADE_OTC_COUNT = 15
FIELD_VOLUME = 16
FIELD_VWAP_OFFICIAL = 17
FIELD_VWAP_ELECTRONIC = 18
FIELD_THEORETICAL_PRICE = 19
FIELD_THEORETICAL_SIZE = 20
FIELD_UPPER_PRICE = 21
FIELD_LOWER_PRICE = 22
FIELD_VARIATION = 23
FIELD_VARIATION_PERCENTAGE = 24


DESCRIPTOR.enum_types_by_name['Field'] = _FIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily/v1/daily_vwap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/daily/v1/daily_vwap.proto',
  package='systemathics.apis.services.daily.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4systemathics/apis/services/daily/v1/daily_vwap.proto\x12#systemathics.apis.services.daily.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xad\x01\n\x11\x44\x61ilyVwapsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"R\n\x12\x44\x61ilyVwapsResponse\x12<\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32..systemathics.apis.services.daily.v1.DailyVwap\"Z\n\tDailyVwap\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x03\x12\r\n\x05score\x18\x04 \x01(\x01\x32\x92\x01\n\x11\x44\x61ilyVwapsService\x12}\n\nDailyVwaps\x12\x36.systemathics.apis.services.daily.v1.DailyVwapsRequest\x1a\x37.systemathics.apis.services.daily.v1.DailyVwapsResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_DAILYVWAPSREQUEST = _descriptor.Descriptor(
  name='DailyVwapsRequest',
  full_name='systemathics.apis.services.daily.v1.DailyVwapsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.daily.v1.DailyVwapsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.daily.v1.DailyVwapsRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.daily.v1.DailyVwapsRequest.adjustment', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=394,
)


_DAILYVWAPSRESPONSE = _descriptor.Descriptor(
  name='DailyVwapsResponse',
  full_name='systemathics.apis.services.daily.v1.DailyVwapsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.daily.v1.DailyVwapsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=478,
)


_DAILYVWAP = _descriptor.Descriptor(
  name='DailyVwap',
  full_name='systemathics.apis.services.daily.v1.DailyVwap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.daily.v1.DailyVwap.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='systemathics.apis.services.daily.v1.DailyVwap.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='systemathics.apis.services.daily.v1.DailyVwap.volume', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='systemathics.apis.services.daily.v1.DailyVwap.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=570,
)

_DAILYVWAPSREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DAILYVWAPSREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DAILYVWAPSRESPONSE.fields_by_name['data'].message_type = _DAILYVWAP
_DAILYVWAP.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['DailyVwapsRequest'] = _DAILYVWAPSREQUEST
DESCRIPTOR.message_types_by_name['DailyVwapsResponse'] = _DAILYVWAPSRESPONSE
DESCRIPTOR.message_types_by_name['DailyVwap'] = _DAILYVWAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DailyVwapsRequest = _reflection.GeneratedProtocolMessageType('DailyVwapsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAPSREQUEST,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwapsRequest)
  })
_sym_db.RegisterMessage(DailyVwapsRequest)

DailyVwapsResponse = _reflection.GeneratedProtocolMessageType('DailyVwapsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAPSRESPONSE,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwapsResponse)
  })
_sym_db.RegisterMessage(DailyVwapsResponse)

DailyVwap = _reflection.GeneratedProtocolMessageType('DailyVwap', (_message.Message,), {
  'DESCRIPTOR' : _DAILYVWAP,
  '__module__' : 'systemathics.apis.services.daily.v1.daily_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily.v1.DailyVwap)
  })
_sym_db.RegisterMessage(DailyVwap)



_DAILYVWAPSSERVICE = _descriptor.ServiceDescriptor(
  name='DailyVwapsService',
  full_name='systemathics.apis.services.daily.v1.DailyVwapsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=573,
  serialized_end=719,
  methods=[
  _descriptor.MethodDescriptor(
    name='DailyVwaps',
    full_name='systemathics.apis.services.daily.v1.DailyVwapsService.DailyVwaps',
    index=0,
    containing_service=None,
    input_type=_DAILYVWAPSREQUEST,
    output_type=_DAILYVWAPSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAILYVWAPSSERVICE)

DESCRIPTOR.services_by_name['DailyVwapsService'] = _DAILYVWAPSSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/corporate_actions/v1/dividends.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/corporate_actions/v1/dividends.proto',
  package='systemathics.apis.services.corporate_actions.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?systemathics/apis/services/corporate_actions/v1/dividends.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\x98\x01\n\x10\x44ividendsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\"\\\n\x11\x44ividendsResponse\x12G\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x39.systemathics.apis.services.corporate_actions.v1.Dividend\"\x97\x01\n\x08\x44ividend\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12K\n\x04type\x18\x02 \x01(\x0e\x32=.systemathics.apis.services.corporate_actions.v1.DividendType\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\r\n\x05score\x18\x04 \x01(\x01*4\n\x0c\x44ividendType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x43\x41SH\x10\x01\x12\t\n\x05STOCK\x10\x02\x32\xa7\x01\n\x10\x44ividendsService\x12\x92\x01\n\tDividends\x12\x41.systemathics.apis.services.corporate_actions.v1.DividendsRequest\x1a\x42.systemathics.apis.services.corporate_actions.v1.DividendsResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])

_DIVIDENDTYPE = _descriptor.EnumDescriptor(
  name='DividendType',
  full_name='systemathics.apis.services.corporate_actions.v1.DividendType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CASH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=646,
  serialized_end=698,
)
_sym_db.RegisterEnumDescriptor(_DIVIDENDTYPE)

DividendType = enum_type_wrapper.EnumTypeWrapper(_DIVIDENDTYPE)
UNSPECIFIED = 0
CASH = 1
STOCK = 2



_DIVIDENDSREQUEST = _descriptor.Descriptor(
  name='DividendsRequest',
  full_name='systemathics.apis.services.corporate_actions.v1.DividendsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.corporate_actions.v1.DividendsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.corporate_actions.v1.DividendsRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=396,
)


_DIVIDENDSRESPONSE = _descriptor.Descriptor(
  name='DividendsResponse',
  full_name='systemathics.apis.services.corporate_actions.v1.DividendsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.corporate_actions.v1.DividendsResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=490,
)


_DIVIDEND = _descriptor.Descriptor(
  name='Dividend',
  full_name='systemathics.apis.services.corporate_actions.v1.Dividend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.corporate_actions.v1.Dividend.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.corporate_actions.v1.Dividend.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='systemathics.apis.services.corporate_actions.v1.Dividend.amount', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='systemathics.apis.services.corporate_actions.v1.Dividend.score', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=644,
)

_DIVIDENDSREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DIVIDENDSREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DIVIDENDSRESPONSE.fields_by_name['data'].message_type = _DIVIDEND
_DIVIDEND.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
_DIVIDEND.fields_by_name['type'].enum_type = _DIVIDENDTYPE
DESCRIPTOR.message_types_by_name['DividendsRequest'] = _DIVIDENDSREQUEST
DESCRIPTOR.message_types_by_name['DividendsResponse'] = _DIVIDENDSRESPONSE
DESCRIPTOR.message_types_by_name['Dividend'] = _DIVIDEND
DESCRIPTOR.enum_types_by_name['DividendType'] = _DIVIDENDTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DividendsRequest = _reflection.GeneratedProtocolMessageType('DividendsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDENDSREQUEST,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.DividendsRequest)
  })
_sym_db.RegisterMessage(DividendsRequest)

DividendsResponse = _reflection.GeneratedProtocolMessageType('DividendsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDENDSRESPONSE,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.DividendsResponse)
  })
_sym_db.RegisterMessage(DividendsResponse)

Dividend = _reflection.GeneratedProtocolMessageType('Dividend', (_message.Message,), {
  'DESCRIPTOR' : _DIVIDEND,
  '__module__' : 'systemathics.apis.services.corporate_actions.v1.dividends_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.corporate_actions.v1.Dividend)
  })
_sym_db.RegisterMessage(Dividend)



_DIVIDENDSSERVICE = _descriptor.ServiceDescriptor(
  name='DividendsService',
  full_name='systemathics.apis.services.corporate_actions.v1.DividendsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=701,
  serialized_end=868,
  methods=[
  _descriptor.MethodDescriptor(
    name='Dividends',
    full_name='systemathics.apis.services.corporate_actions.v1.DividendsService.Dividends',
    index=0,
    containing_service=None,
    input_type=_DIVIDENDSREQUEST,
    output_type=_DIVIDENDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DIVIDENDSSERVICE)

DESCRIPTOR.services_by_name['DividendsService'] = _DIVIDENDSSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_sector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/static_data/v1/static_sector.proto',
  package='systemathics.apis.services.static_data.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=systemathics/apis/services/static_data/v1/static_sector.proto\x12)systemathics.apis.services.static_data.v1\"Q\n\x13StaticSectorRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0e\n\x04\x63ode\x18\x02 \x01(\tH\x00\x12\x0f\n\x05level\x18\x03 \x01(\x05H\x00\x42\x07\n\x05value\"z\n\x14StaticSectorResponse\x12>\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.static_data.v1.Level\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"U\n\x05Level\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Index\x18\x02 \x01(\x05\x12\x0c\n\x04\x43ode\x18\x03 \x01(\t\x12\x12\n\ndefinition\x18\x04 \x01(\t\x12\r\n\x05label\x18\x05 \x01(\t2\xa7\x01\n\x13StaticSectorService\x12\x8f\x01\n\x0cStaticSector\x12>.systemathics.apis.services.static_data.v1.StaticSectorRequest\x1a?.systemathics.apis.services.static_data.v1.StaticSectorResponseb\x06proto3'
)




_STATICSECTORREQUEST = _descriptor.Descriptor(
  name='StaticSectorRequest',
  full_name='systemathics.apis.services.static_data.v1.StaticSectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='systemathics.apis.services.static_data.v1.StaticSectorRequest.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='systemathics.apis.services.static_data.v1.StaticSectorRequest.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='systemathics.apis.services.static_data.v1.StaticSectorRequest.level', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.StaticSectorRequest.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=108,
  serialized_end=189,
)


_STATICSECTORRESPONSE = _descriptor.Descriptor(
  name='StaticSectorResponse',
  full_name='systemathics.apis.services.static_data.v1.StaticSectorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.static_data.v1.StaticSectorResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='systemathics.apis.services.static_data.v1.StaticSectorResponse.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='systemathics.apis.services.static_data.v1.StaticSectorResponse.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=313,
)


_LEVEL = _descriptor.Descriptor(
  name='Level',
  full_name='systemathics.apis.services.static_data.v1.Level',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='systemathics.apis.services.static_data.v1.Level.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Index', full_name='systemathics.apis.services.static_data.v1.Level.Index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Code', full_name='systemathics.apis.services.static_data.v1.Level.Code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='definition', full_name='systemathics.apis.services.static_data.v1.Level.definition', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='systemathics.apis.services.static_data.v1.Level.label', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=400,
)

_STATICSECTORREQUEST.oneofs_by_name['value'].fields.append(
  _STATICSECTORREQUEST.fields_by_name['code'])
_STATICSECTORREQUEST.fields_by_name['code'].containing_oneof = _STATICSECTORREQUEST.oneofs_by_name['value']
_STATICSECTORREQUEST.oneofs_by_name['value'].fields.append(
  _STATICSECTORREQUEST.fields_by_name['level'])
_STATICSECTORREQUEST.fields_by_name['level'].containing_oneof = _STATICSECTORREQUEST.oneofs_by_name['value']
_STATICSECTORRESPONSE.fields_by_name['data'].message_type = _LEVEL
DESCRIPTOR.message_types_by_name['StaticSectorRequest'] = _STATICSECTORREQUEST
DESCRIPTOR.message_types_by_name['StaticSectorResponse'] = _STATICSECTORRESPONSE
DESCRIPTOR.message_types_by_name['Level'] = _LEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StaticSectorRequest = _reflection.GeneratedProtocolMessageType('StaticSectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATICSECTORREQUEST,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticSectorRequest)
  })
_sym_db.RegisterMessage(StaticSectorRequest)

StaticSectorResponse = _reflection.GeneratedProtocolMessageType('StaticSectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATICSECTORRESPONSE,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticSectorResponse)
  })
_sym_db.RegisterMessage(StaticSectorResponse)

Level = _reflection.GeneratedProtocolMessageType('Level', (_message.Message,), {
  'DESCRIPTOR' : _LEVEL,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_sector_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.Level)
  })
_sym_db.RegisterMessage(Level)



_STATICSECTORSERVICE = _descriptor.ServiceDescriptor(
  name='StaticSectorService',
  full_name='systemathics.apis.services.static_data.v1.StaticSectorService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=403,
  serialized_end=570,
  methods=[
  _descriptor.MethodDescriptor(
    name='StaticSector',
    full_name='systemathics.apis.services.static_data.v1.StaticSectorService.StaticSector',
    index=0,
    containing_service=None,
    input_type=_STATICSECTORREQUEST,
    output_type=_STATICSECTORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STATICSECTORSERVICE)

DESCRIPTOR.services_by_name['StaticSectorService'] = _STATICSECTORSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_macd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/daily_analytics/v1/daily_macd.proto',
  package='systemathics.apis.services.daily_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>systemathics/apis/services/daily_analytics/v1/daily_macd.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xc9\x01\n\x10\x44\x61ilyMacdRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0c\n\x04long\x18\x03 \x01(\x05\x12\r\n\x05short\x18\x04 \x01(\x05\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"_\n\x11\x44\x61ilyMacdResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.daily_analytics.v1.DailyMacdData\"j\n\rDailyMacdData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0c\n\x04macd\x18\x03 \x01(\x01\x12\r\n\x05short\x18\x04 \x01(\x01\x12\x0c\n\x04long\x18\x05 \x01(\x01\x32\xa3\x01\n\x10\x44\x61ilyMacdService\x12\x8e\x01\n\tDailyMacd\x12?.systemathics.apis.services.daily_analytics.v1.DailyMacdRequest\x1a@.systemathics.apis.services.daily_analytics.v1.DailyMacdResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_DAILYMACDREQUEST = _descriptor.Descriptor(
  name='DailyMacdRequest',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdRequest.long', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdRequest.short', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdRequest.adjustment', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=442,
)


_DAILYMACDRESPONSE = _descriptor.Descriptor(
  name='DailyMacdResponse',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=539,
)


_DAILYMACDDATA = _descriptor.Descriptor(
  name='DailyMacdData',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdData.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdData.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='macd', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdData.macd', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdData.short', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long', full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdData.long', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=647,
)

_DAILYMACDREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DAILYMACDREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DAILYMACDRESPONSE.fields_by_name['data'].message_type = _DAILYMACDDATA
_DAILYMACDDATA.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['DailyMacdRequest'] = _DAILYMACDREQUEST
DESCRIPTOR.message_types_by_name['DailyMacdResponse'] = _DAILYMACDRESPONSE
DESCRIPTOR.message_types_by_name['DailyMacdData'] = _DAILYMACDDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DailyMacdRequest = _reflection.GeneratedProtocolMessageType('DailyMacdRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYMACDREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyMacdRequest)
  })
_sym_db.RegisterMessage(DailyMacdRequest)

DailyMacdResponse = _reflection.GeneratedProtocolMessageType('DailyMacdResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYMACDRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyMacdResponse)
  })
_sym_db.RegisterMessage(DailyMacdResponse)

DailyMacdData = _reflection.GeneratedProtocolMessageType('DailyMacdData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYMACDDATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyMacdData)
  })
_sym_db.RegisterMessage(DailyMacdData)



_DAILYMACDSERVICE = _descriptor.ServiceDescriptor(
  name='DailyMacdService',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=650,
  serialized_end=813,
  methods=[
  _descriptor.MethodDescriptor(
    name='DailyMacd',
    full_name='systemathics.apis.services.daily_analytics.v1.DailyMacdService.DailyMacd',
    index=0,
    containing_service=None,
    input_type=_DAILYMACDREQUEST,
    output_type=_DAILYMACDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAILYMACDSERVICE)

DESCRIPTOR.services_by_name['DailyMacdService'] = _DAILYMACDSERVICE

# @@protoc_insertion_point(module_scope)
